summaryrefslogtreecommitdiffstats
path: root/libkonq
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:11:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:11:21 -0600
commitf537c21b68e08f649b1b297bce8f3904603137e0 (patch)
treefb33065387509dea898c90022ddec9c3f8ede86d /libkonq
parentdc5f267664506a312203c26bfe9001a448b0bb0f (diff)
downloadtdebase-f537c21b68e08f649b1b297bce8f3904603137e0.tar.gz
tdebase-f537c21b68e08f649b1b297bce8f3904603137e0.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'libkonq')
-rw-r--r--libkonq/knewmenu.cc34
-rw-r--r--libkonq/knewmenu.h6
-rw-r--r--libkonq/konq_dirpart.cc24
-rw-r--r--libkonq/konq_dirpart.h18
-rw-r--r--libkonq/konq_popupmenu.cc44
-rw-r--r--libkonq/konq_popupmenu.h18
-rw-r--r--libkonq/konq_xmlguiclient.cc4
-rw-r--r--libkonq/konq_xmlguiclient.h2
8 files changed, 75 insertions, 75 deletions
diff --git a/libkonq/knewmenu.cc b/libkonq/knewmenu.cc
index 2e6247c21..52bb605a1 100644
--- a/libkonq/knewmenu.cc
+++ b/libkonq/knewmenu.cc
@@ -57,14 +57,14 @@ class KNewMenu::KNewMenuPrivate
{
public:
KNewMenuPrivate() : m_parentWidget(0) {}
- KActionCollection * m_actionCollection;
+ TDEActionCollection * m_actionCollection;
TQString m_destPath;
TQWidget *m_parentWidget;
- KActionMenu *m_menuDev;
+ TDEActionMenu *m_menuDev;
};
-KNewMenu::KNewMenu( KActionCollection * _collec, const char *name ) :
- KActionMenu( i18n( "Create New" ), "filenew", _collec, name ),
+KNewMenu::KNewMenu( TDEActionCollection * _collec, const char *name ) :
+ TDEActionMenu( i18n( "Create New" ), "filenew", _collec, name ),
menuItemsVersion( 0 )
{
//kdDebug(1203) << "KNewMenu::KNewMenu " << this << endl;
@@ -75,8 +75,8 @@ KNewMenu::KNewMenu( KActionCollection * _collec, const char *name ) :
makeMenus();
}
-KNewMenu::KNewMenu( KActionCollection * _collec, TQWidget *parentWidget, const char *name ) :
- KActionMenu( i18n( "Create New" ), "filenew", _collec, name ),
+KNewMenu::KNewMenu( TDEActionCollection * _collec, TQWidget *parentWidget, const char *name ) :
+ TDEActionMenu( i18n( "Create New" ), "filenew", _collec, name ),
menuItemsVersion( 0 )
{
d = new KNewMenuPrivate;
@@ -93,7 +93,7 @@ KNewMenu::~KNewMenu()
void KNewMenu::makeMenus()
{
- d->m_menuDev = new KActionMenu( i18n( "Link to Device" ), "kcmdevices", d->m_actionCollection, "devnew" );
+ d->m_menuDev = new TDEActionMenu( i18n( "Link to Device" ), "kcmdevices", d->m_actionCollection, "devnew" );
}
void KNewMenu::slotCheckUpToDate( )
@@ -106,8 +106,8 @@ void KNewMenu::slotCheckUpToDate( )
//kdDebug(1203) << "KNewMenu::slotCheckUpToDate() : recreating actions" << endl;
// We need to clean up the action collection
// We look for our actions using the group
- TQValueList<KAction*> actions = d->m_actionCollection->actions( "KNewMenu" );
- for( TQValueListIterator<KAction*> it = actions.begin(); it != actions.end(); ++it )
+ TQValueList<TDEAction*> actions = d->m_actionCollection->actions( "KNewMenu" );
+ for( TQValueListIterator<TDEAction*> it = actions.begin(); it != actions.end(); ++it )
{
remove( *it );
d->m_actionCollection->remove( *it );
@@ -204,7 +204,7 @@ void KNewMenu::fillMenu()
popupMenu()->clear();
d->m_menuDev->popupMenu()->clear();
- KAction *linkURL = 0, *linkApp = 0; // these shall be put at special positions
+ TDEAction *linkURL = 0, *linkApp = 0; // these shall be put at special positions
int i = 1; // was 2 when there was Folder
TQValueList<Entry>::Iterator templ = s_templatesList->begin();
@@ -220,8 +220,8 @@ void KNewMenu::fillMenu()
bool bSkip = false;
- TQValueList<KAction*> actions = d->m_actionCollection->actions();
- TQValueListIterator<KAction*> it = actions.begin();
+ TQValueList<TDEAction*> actions = d->m_actionCollection->actions();
+ TQValueListIterator<TDEAction*> it = actions.begin();
for( ; it != actions.end() && !bSkip; ++it )
{
if ( (*it)->text() == (*templ).text )
@@ -238,17 +238,17 @@ void KNewMenu::fillMenu()
// The best way to identify the "Create Directory", "Link to Location", "Link to Application" was the template
if ( (*templ).templatePath.endsWith( "emptydir" ) )
{
- KAction * act = new KAction( (*templ).text, (*templ).icon, 0, this, TQT_SLOT( slotNewDir() ),
+ TDEAction * act = new TDEAction( (*templ).text, (*templ).icon, 0, this, TQT_SLOT( slotNewDir() ),
d->m_actionCollection, TQCString().sprintf("newmenu%d", i ) );
act->setGroup( "KNewMenu" );
act->plug( popupMenu() );
- KActionSeparator *sep = new KActionSeparator();
+ TDEActionSeparator *sep = new TDEActionSeparator();
sep->plug( popupMenu() );
}
else
{
- KAction * act = new KAction( (*templ).text, (*templ).icon, 0, this, TQT_SLOT( slotNewFile() ),
+ TDEAction * act = new TDEAction( (*templ).text, (*templ).icon, 0, this, TQT_SLOT( slotNewFile() ),
d->m_actionCollection, TQCString().sprintf("newmenu%d", i ) );
act->setGroup( "KNewMenu" );
@@ -277,12 +277,12 @@ void KNewMenu::fillMenu()
} else { // Separate system from personal templates
Q_ASSERT( (*templ).entryType != 0 );
- KActionSeparator * act = new KActionSeparator();
+ TDEActionSeparator * act = new TDEActionSeparator();
act->plug( popupMenu() );
}
}
- KActionSeparator * act = new KActionSeparator();
+ TDEActionSeparator * act = new TDEActionSeparator();
act->plug( popupMenu() );
if ( linkURL ) linkURL->plug( popupMenu() );
if ( linkApp ) linkApp->plug( popupMenu() );
diff --git a/libkonq/knewmenu.h b/libkonq/knewmenu.h
index 9e2181329..17239f119 100644
--- a/libkonq/knewmenu.h
+++ b/libkonq/knewmenu.h
@@ -49,7 +49,7 @@ class TQPopupMenu;
* Ideas and code for the new template handling mechanism ('link' desktop files)
* from Christoph Pickart <pickart@iam.uni-bonn.de>
*/
-class LIBKONQ_EXPORT KNewMenu : public KActionMenu
+class LIBKONQ_EXPORT KNewMenu : public TDEActionMenu
{
Q_OBJECT
public:
@@ -57,8 +57,8 @@ public:
/**
* Constructor
*/
- KNewMenu( KActionCollection * _collec, const char *name=0L );
- KNewMenu( KActionCollection * _collec, TQWidget *parentWidget, const char *name=0L );
+ KNewMenu( TDEActionCollection * _collec, const char *name=0L );
+ KNewMenu( TDEActionCollection * _collec, TQWidget *parentWidget, const char *name=0L );
virtual ~KNewMenu();
/**
diff --git a/libkonq/konq_dirpart.cc b/libkonq/konq_dirpart.cc
index 2257d3f56..46226a6d0 100644
--- a/libkonq/konq_dirpart.cc
+++ b/libkonq/konq_dirpart.cc
@@ -50,8 +50,8 @@ class KonqDirPart::KonqDirPartPrivate
public:
KonqDirPartPrivate() : dirLister( 0 ) {}
TQStringList mimeFilters;
- KToggleAction *aEnormousIcons;
- KToggleAction *aSmallMediumIcons;
+ TDEToggleAction *aEnormousIcons;
+ TDEToggleAction *aSmallMediumIcons;
TQValueVector<int> iconSize;
KDirLister* dirLister;
@@ -137,18 +137,18 @@ KonqDirPart::KonqDirPart( TQObject *parent, const char *name )
actionCollection()->setHighlightingEnabled( true );
- m_paIncIconSize = new KAction( i18n( "Enlarge Icons" ), "viewmag+", 0, this, TQT_SLOT( slotIncIconSize() ), actionCollection(), "incIconSize" );
- m_paDecIconSize = new KAction( i18n( "Shrink Icons" ), "viewmag-", 0, this, TQT_SLOT( slotDecIconSize() ), actionCollection(), "decIconSize" );
+ m_paIncIconSize = new TDEAction( i18n( "Enlarge Icons" ), "viewmag+", 0, this, TQT_SLOT( slotIncIconSize() ), actionCollection(), "incIconSize" );
+ m_paDecIconSize = new TDEAction( i18n( "Shrink Icons" ), "viewmag-", 0, this, TQT_SLOT( slotDecIconSize() ), actionCollection(), "decIconSize" );
- m_paDefaultIcons = new KRadioAction( i18n( "&Default Size" ), 0, actionCollection(), "modedefault" );
- d->aEnormousIcons = new KRadioAction( i18n( "&Huge" ), 0,
+ m_paDefaultIcons = new TDERadioAction( i18n( "&Default Size" ), 0, actionCollection(), "modedefault" );
+ d->aEnormousIcons = new TDERadioAction( i18n( "&Huge" ), 0,
actionCollection(), "modeenormous" );
- m_paHugeIcons = new KRadioAction( i18n( "&Very Large" ), 0, actionCollection(), "modehuge" );
- m_paLargeIcons = new KRadioAction( i18n( "&Large" ), 0, actionCollection(), "modelarge" );
- m_paMediumIcons = new KRadioAction( i18n( "&Medium" ), 0, actionCollection(), "modemedium" );
- d->aSmallMediumIcons = new KRadioAction( i18n( "&Small" ), 0,
+ m_paHugeIcons = new TDERadioAction( i18n( "&Very Large" ), 0, actionCollection(), "modehuge" );
+ m_paLargeIcons = new TDERadioAction( i18n( "&Large" ), 0, actionCollection(), "modelarge" );
+ m_paMediumIcons = new TDERadioAction( i18n( "&Medium" ), 0, actionCollection(), "modemedium" );
+ d->aSmallMediumIcons = new TDERadioAction( i18n( "&Small" ), 0,
actionCollection(), "modesmallmedium" );
- m_paSmallIcons = new KRadioAction( i18n( "&Tiny" ), 0, actionCollection(), "modesmall" );
+ m_paSmallIcons = new TDERadioAction( i18n( "&Tiny" ), 0, actionCollection(), "modesmall" );
m_paDefaultIcons->setExclusiveGroup( "ViewMode" );
d->aEnormousIcons->setExclusiveGroup( "ViewMode" );
@@ -219,7 +219,7 @@ KonqDirPart::KonqDirPart( TQObject *parent, const char *name )
m_iIconSize[4] = KIcon::SizeHuge;
// ... up to here
- KAction *a = new KAction( i18n( "Configure Background..." ), "background", 0, this, TQT_SLOT( slotBackgroundSettings() ),
+ TDEAction *a = new TDEAction( i18n( "Configure Background..." ), "background", 0, this, TQT_SLOT( slotBackgroundSettings() ),
actionCollection(), "bgsettings" );
a->setToolTip( i18n( "Allows choosing of background settings for this view" ) );
diff --git a/libkonq/konq_dirpart.h b/libkonq/konq_dirpart.h
index 12e9de49d..6b24bf9c5 100644
--- a/libkonq/konq_dirpart.h
+++ b/libkonq/konq_dirpart.h
@@ -32,8 +32,8 @@ class KDirLister;
namespace KParts { class BrowserExtension; }
class KonqPropsView;
class TQScrollView;
-class KAction;
-class KToggleAction;
+class TDEAction;
+class TDEToggleAction;
class KonqDirPartBrowserExtension;
class LIBKONQ_EXPORT KonqDirPart: public KParts::ReadOnlyPart
@@ -299,13 +299,13 @@ protected:
KonqPropsView * m_pProps;
- KAction *m_paIncIconSize;
- KAction *m_paDecIconSize;
- KToggleAction *m_paDefaultIcons;
- KToggleAction *m_paHugeIcons;
- KToggleAction *m_paLargeIcons;
- KToggleAction *m_paMediumIcons;
- KToggleAction *m_paSmallIcons;
+ TDEAction *m_paIncIconSize;
+ TDEAction *m_paDecIconSize;
+ TDEToggleAction *m_paDefaultIcons;
+ TDEToggleAction *m_paHugeIcons;
+ TDEToggleAction *m_paLargeIcons;
+ TDEToggleAction *m_paMediumIcons;
+ TDEToggleAction *m_paSmallIcons;
KParts::ReadOnlyPart * m_findPart;
KonqDirPartBrowserExtension * m_extension;
diff --git a/libkonq/konq_popupmenu.cc b/libkonq/konq_popupmenu.cc
index 9d25cf794..8dea08489 100644
--- a/libkonq/konq_popupmenu.cc
+++ b/libkonq/konq_popupmenu.cc
@@ -190,7 +190,7 @@ ServiceList* PopupServices::selectList( const TQString& priority, const TQString
KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
KURL viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
bool showProperties )
: TQPopupMenu( 0L, "konq_popupmenu" ),
@@ -203,7 +203,7 @@ KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
KURL viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
TQWidget * parentWidget,
bool showProperties )
@@ -215,7 +215,7 @@ KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
KonqPopupMenu::KonqPopupMenu( KBookmarkManager *mgr, const KFileItemList &items,
const KURL& viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
TQWidget * parentWidget,
KonqPopupFlags kpf,
@@ -286,7 +286,7 @@ int KonqPopupMenu::insertServices(const ServiceList& list,
TQCString name;
name.setNum( id );
name.prepend( isBuiltin ? "builtinservice_" : "userservice_" );
- KAction * act = new KAction( TQString((*it).m_strName).replace('&',"&&"), 0,
+ TDEAction * act = new TDEAction( TQString((*it).m_strName).replace('&',"&&"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotRunService() ),
&m_ownActions, name );
@@ -481,13 +481,13 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
//////////////////////////////////////////////////////////////////////////
- KAction * act;
+ TDEAction * act;
if (!isCurrentTrash)
addMerge( "konqueror" );
bool isKDesktop = TQCString( kapp->name() ) == "kdesktop";
- KAction *actNewWindow = 0;
+ TDEAction *actNewWindow = 0;
if (( kpf & ShowProperties ) && isKDesktop &&
!kapp->authorize("editable_desktop_icons"))
@@ -500,7 +500,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
if ( ((kpf & ShowNewWindow) != 0) && sReading )
{
TQString openStr = isKDesktop ? i18n( "&Open" ) : i18n( "Open in New &Window" );
- actNewWindow = new KAction( openStr, "window_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupNewView() ), &m_ownActions, "newview" );
+ actNewWindow = new TDEAction( openStr, "window_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupNewView() ), &m_ownActions, "newview" );
}
if ( actNewWindow && !isKDesktop )
@@ -529,14 +529,14 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
{
if (d->m_itemFlags & KParts::BrowserExtension::ShowCreateDirectory)
{
- KAction *actNewDir = new KAction( i18n( "Create &Folder..." ), "folder_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupNewDir() ), &m_ownActions, "newdir" );
+ TDEAction *actNewDir = new TDEAction( i18n( "Create &Folder..." ), "folder_new", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupNewDir() ), &m_ownActions, "newdir" );
addAction( actNewDir );
addSeparator();
}
}
} else if ( isIntoTrash ) {
// Trashed item, offer restoring
- act = new KAction( i18n( "&Restore" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupRestoreTrashedItems() ), &m_ownActions, "restore" );
+ act = new TDEAction( i18n( "&Restore" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupRestoreTrashedItems() ), &m_ownActions, "restore" );
addAction( act );
}
@@ -607,7 +607,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
}
if ( isCurrentTrash )
{
- act = new KAction( i18n( "&Empty Trash Bin" ), "emptytrash", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupEmptyTrashBin() ), &m_ownActions, "empytrash" );
+ act = new TDEAction( i18n( "&Empty Trash Bin" ), "emptytrash", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupEmptyTrashBin() ), &m_ownActions, "empytrash" );
KSimpleConfig trashConfig( "trashrc", true );
trashConfig.setGroup( "Status" );
act->setEnabled( !trashConfig.readBoolEntry( "Empty", true ) );
@@ -640,10 +640,10 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
else
caption = i18n("&Bookmark This File");
- act = new KAction( caption, "bookmark_add", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupAddToBookmark() ), &m_ownActions, "bookmark_add" );
+ act = new TDEAction( caption, "bookmark_add", 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupAddToBookmark() ), &m_ownActions, "bookmark_add" );
if (m_lstItems.count() > 1)
act->setEnabled(false);
- if (kapp->authorizeKAction("bookmarks"))
+ if (kapp->authorizeTDEAction("bookmarks"))
addAction( act );
if (bIsLink)
addGroup( "linkactions" );
@@ -849,7 +849,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
TDETrader::OfferList offers;
- if (kapp->authorizeKAction("openwith"))
+ if (kapp->authorizeTDEAction("openwith"))
{
TQString constraint = "Type == 'Application' and DesktopEntryName != 'kfmclient' and DesktopEntryName != 'kfmclient_dir' and DesktopEntryName != 'kfmclient_html'";
TQString subConstraint = " and '%1' in ServiceTypes";
@@ -924,7 +924,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
if ( menu == m_menuElement ) // no submenu -> prefix single offer
actionName = i18n( "Open with %1" ).arg( actionName );
- act = new KAction( actionName, (*it)->pixmap( KIcon::Small ), 0,
+ act = new TDEAction( actionName, (*it)->pixmap( KIcon::Small ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotRunService() ),
&m_ownActions, nam.prepend( "appservice_" ) );
addAction( act, menu );
@@ -942,12 +942,12 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
{
openWithActionName = i18n( "&Open With..." );
}
- KAction *openWithAct = new KAction( openWithActionName, 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupOpenWith() ), &m_ownActions, "openwith" );
+ TDEAction *openWithAct = new TDEAction( openWithActionName, 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupOpenWith() ), &m_ownActions, "openwith" );
addAction( openWithAct, menu );
}
else // no app offers -> Open With...
{
- act = new KAction( i18n( "&Open With..." ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupOpenWith() ), &m_ownActions, "openwith" );
+ act = new TDEAction( i18n( "&Open With..." ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupOpenWith() ), &m_ownActions, "openwith" );
addAction( act );
}
@@ -1001,7 +1001,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
if ( KPropertiesDialog::canDisplay( m_lstItems ) && (kpf & ShowProperties) )
{
- act = new KAction( i18n( "&Properties" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupProperties() ),
+ act = new TDEAction( i18n( "&Properties" ), 0, TQT_TQOBJECT(this), TQT_SLOT( slotPopupProperties() ),
&m_ownActions, "properties" );
addAction( act );
}
@@ -1015,7 +1015,7 @@ void KonqPopupMenu::setup(KonqPopupFlags kpf)
if ( KFileShare::authorization() == KFileShare::Authorized )
{
addSeparator();
- act = new KAction( i18n("Share"), 0, TQT_TQOBJECT(this), TQT_SLOT( slotOpenShareFileDialog() ),
+ act = new TDEAction( i18n("Share"), 0, TQT_TQOBJECT(this), TQT_SLOT( slotOpenShareFileDialog() ),
&m_ownActions, "sharefile" );
addAction( act );
}
@@ -1146,10 +1146,10 @@ KPropertiesDialog* KonqPopupMenu::showPropertiesDialog()
return new KPropertiesDialog( m_lstItems, d->m_parentWidget );
}
-KAction *KonqPopupMenu::action( const TQDomElement &element ) const
+TDEAction *KonqPopupMenu::action( const TQDomElement &element ) const
{
TQCString name = element.attribute( attrName ).ascii();
- KAction *res = m_ownActions.action( static_cast<const char *>(name) );
+ TDEAction *res = m_ownActions.action( static_cast<const char *>(name) );
if ( !res )
res = m_actions.action( static_cast<const char *>(name) );
@@ -1160,9 +1160,9 @@ KAction *KonqPopupMenu::action( const TQDomElement &element ) const
return res;
}
-KActionCollection *KonqPopupMenu::actionCollection() const
+TDEActionCollection *KonqPopupMenu::actionCollection() const
{
- return const_cast<KActionCollection *>( &m_ownActions );
+ return const_cast<TDEActionCollection *>( &m_ownActions );
}
TQString KonqPopupMenu::mimeType() const
diff --git a/libkonq/konq_xmlguiclient.cc b/libkonq/konq_xmlguiclient.cc
index 69afd7b0a..ec3fed584 100644
--- a/libkonq/konq_xmlguiclient.cc
+++ b/libkonq/konq_xmlguiclient.cc
@@ -70,7 +70,7 @@ TQDomDocument KonqXMLGUIClient::domDocument() const
return m_doc;
}
-void KonqXMLGUIClient::addAction( KAction *act, const TQDomElement &menu )
+void KonqXMLGUIClient::addAction( TDEAction *act, const TQDomElement &menu )
{
addAction( act->name(), menu );
}
@@ -79,7 +79,7 @@ void KonqXMLGUIClient::addAction( const char *name, const TQDomElement &menu )
{
static const TQString& tagAction = TDEGlobal::staticQString( "action" );
- if (!kapp->authorizeKAction(name))
+ if (!kapp->authorizeTDEAction(name))
return;
handlePendingSeparator();
diff --git a/libkonq/konq_xmlguiclient.h b/libkonq/konq_xmlguiclient.h
index 772554dd2..c219c6488 100644
--- a/libkonq/konq_xmlguiclient.h
+++ b/libkonq/konq_xmlguiclient.h
@@ -45,7 +45,7 @@ public:
TQDomElement DomElement( ) const; // KDE4: s/D/d/
protected:
- void addAction( KAction *action, const TQDomElement &menu = TQDomElement() );
+ void addAction( TDEAction *action, const TQDomElement &menu = TQDomElement() );
void addAction( const char *name, const TQDomElement &menu = TQDomElement() );
void addSeparator( const TQDomElement &menu = TQDomElement() );
/// only add a separator if an action is added afterwards
diff --git a/libkonq/konq_popupmenu.h b/libkonq/konq_popupmenu.h
index 130e9ae6f..01b1247ce 100644
--- a/libkonq/konq_popupmenu.h
+++ b/libkonq/konq_popupmenu.h
@@ -45,7 +45,7 @@ class KService;
class KonqPopupMenuPlugin;
class KBookmarkManager;
// TODO KDE4: change base class to KPopupMenu, see KAction::slotPopupActivated()
/**
* This class implements the popup menu for URLs in konqueror and kdesktop
* It's usage is very simple : on right click, create the KonqPopupMenu instance
@@ -76,7 +76,7 @@ public:
KonqPopupMenu( KBookmarkManager* manager,
const KFileItemList &items,
KURL viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
bool showPropertiesAndFileType = true ) KDE_DEPRECATED;
@@ -87,7 +87,7 @@ public:
KonqPopupMenu( KBookmarkManager* manager,
const KFileItemList &items,
KURL viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
TQWidget * parentWidget,
bool showPropertiesAndFileType = true ) KDE_DEPRECATED;
@@ -115,7 +115,7 @@ public:
KonqPopupMenu( KBookmarkManager* manager,
const KFileItemList &items,
const KURL& viewURL,
- KActionCollection & actions,
+ TDEActionCollection & actions,
KNewMenu * newMenu,
TQWidget * parentWidget,
KonqPopupFlags kpf,
@@ -151,10 +151,10 @@ public:
/**
* Reimplemented for internal purpose
*/
- virtual KAction *action( const TQDomElement &element ) const;
+ virtual TDEAction *action( const TQDomElement &element ) const;
- virtual KActionCollection *actionCollection() const;
+ virtual TDEActionCollection *actionCollection() const;
TQString mimeType( ) const;
KURL url( ) const;
KFileItemList fileItemList() const;
@@ -174,8 +174,8 @@ public slots: // KDE4: why public?
void slotOpenShareFileDialog();
protected:
- KActionCollection &m_actions;
- KActionCollection m_ownActions;
+ TDEActionCollection &m_actions;
+ TDEActionCollection m_ownActions;
private slots:
void slotLocalURL( TDEIO::Job *, const KURL&, bool );
@@ -215,7 +215,7 @@ public:
* Constructor
* If you want to insert a dynamic item or menu to konqpopupmenu
* this class is the right choice.
- * Create a KAction and use _popup->addAction(new KAction );
+ * Create a TDEAction and use _popup->addAction(new TDEAction );
* If you want to create a submenu use _popup->addGroup( );
*/
KonqPopupMenuPlugin( KonqPopupMenu *_popup, const char *name ); // this should also be the parent
@@ -45,7 +45,7 @@ class KService;
class KonqPopupMenuPlugin;
class KBookmarkManager;
-// TODO KDE4: change base class to KPopupMenu, see KAction::slotPopupActivated()
+// TODO KDE4: change base class to TDEPopupMenu, see TDEAction::slotPopupActivated()
/**
* This class implements the popup menu for URLs in konqueror and kdesktop